@@ -1,23 +1,20 @@
-// $Id: ChessBoard.cpp,v 1.3 2003/12/06 16:44:51 psy Exp $
 //
 // ChessBoard.cpp: implementation of the ChessBoard class.
 //
-// Copyright (C) 2003 Tristan Miller <psychonaut@nothingisreal.com>
-//  
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of the
-// License, or (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// General Public License for more details.
-// 
+// Copyright (C) 2003-2016 Tristan Miller <psychonaut@nothingisreal.com>
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -401,7 +398,7 @@ bool ChessBoard::can_move(int from, int to, piece_type promotion) const {
 //  - returns a list of all squares where the king may move
 // -------------------------------------------------------------------
 move_list ChessBoard::mobility_king(int from) const {
-    move m;
+    chessmove m;
     move_list ml;
     m.promotion=Empty;
     m.from=from;
@@ -457,7 +454,7 @@ move_list ChessBoard::mobility_king(int from) const {
 //  - returns a list of all squares where the knight may move
 // -------------------------------------------------------------------
 move_list ChessBoard::mobility_knight(int from) const {
-    move m;
+    chessmove m;
     move_list ml;
     m.promotion=Empty;
     m.from=from;
@@ -482,7 +479,7 @@ move_list ChessBoard::mobility_knight(int from) const {
 //  - returns a list of all squares where the pawn may move
 // -------------------------------------------------------------------
 move_list ChessBoard::mobility_pawn(int from) const {
-    move m;
+    chessmove m;
     move_list ml;
     m.promotion=Empty;
     m.from=from;
@@ -540,7 +537,7 @@ move_list ChessBoard::mobility_pawn(int from) const {
 //  - returns a list of all squares where the rook may move
 // -------------------------------------------------------------------
 move_list ChessBoard::mobility_rook(int from) const {
-    move m;
+    chessmove m;
     move_list ml;
     m.promotion=Empty;
     m.from=from;
@@ -568,7 +565,7 @@ move_list ChessBoard::mobility_rook(int from) const {
 //  - returns a list of all squares where the bishop may move
 // -------------------------------------------------------------------
 move_list ChessBoard::mobility_bishop(int from) const {
-    move m;
+    chessmove m;
     move_list ml;
     m.promotion=Empty;
     m.from=from;
@@ -681,7 +678,7 @@ bool ChessBoard::is_attacked(bool by_white, int to) const {
 // -------------------------------------------------------------------
 // Determine whether the given move puts one's own king in check
 // -------------------------------------------------------------------
-bool ChessBoard::causes_check(const move& m) const {
+bool ChessBoard::causes_check(const chessmove& m) const {
     bool w_turn=is_white(square[m.from]);
     ChessBoard c=*this;
     piece_type promotion=m.promotion;
