@@ -1,28 +1,26 @@
-// $Id: ComputerPlayer.cpp,v 1.3 2003/12/06 16:44:51 psy Exp $
 //
 // ComputerPlayer.cpp: implementation of the ComputerPlayer class.
 //
-// Copyright (C) 2003 Tristan Miller <psychonaut@nothingisreal.com>
-//  
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of the
-// License, or (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// General Public License for more details.
-// 
+// Copyright (C) 2003-2016 Tristan Miller <psychonaut@nothingisreal.com>
+//
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 //////////////////////////////////////////////////////////////////////
 
 #include "stdafx.h"
 #include "ComputerPlayer.h"
+#include <climits>
 
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
@@ -92,7 +90,7 @@ void ComputerPlayer::set_stats() {
         &r_king_prox, &r_mobility, &r_xmobility, &r_pawns, &r_mobilitybonus,
         &r_xmobilitybonus, &q_material, &q_king_prox, &q_centre_prox,
         &k_centre_dist, &k_pawn, &k_castle, &ply, NULL};
-    char *desc[] = {"draw value", "endgame threshold", "pawn material",
+    const char *desc[] = {"draw value", "endgame threshold", "pawn material",
         "doubled pawn", "backward pawn", "pawn proximity to opposite edge",
         "isolated pawn on file 1 or 8", "isolated pawn on file 2 or 7",
         "isolated pawn on file 3 or 6", "isolated pawn on file 4 or 5",
@@ -140,7 +138,7 @@ void ComputerPlayer::set_stats() {
 // -------------------------------------------------------------------
 string ComputerPlayer::get_command(const ChessBoard &b) const {
     if (b.in_progress) {
-        move mv;
+        chessmove mv;
         long v=alphabeta(b, ply,-LONG_MAX,LONG_MAX,mv);
         // To offer draw:
         // if v<DRAW_THRESHOLD && haven't_offered_draw_in_a_while then
@@ -295,7 +293,7 @@ long ComputerPlayer::get_score(const ChessBoard &b) const {
 // Alpha beta game tree search
 // -------------------------------------------------------------------
 long ComputerPlayer::alphabeta(const ChessBoard &b, long depth, long alpha,
-    long beta, move &chosen_move) const {
+    long beta, chessmove &chosen_move) const {
     if (depth==0)
         return get_score(b);
 
@@ -304,7 +302,7 @@ long ComputerPlayer::alphabeta(const ChessBoard &b, long depth, long alpha,
         return get_score(b);
 
     long best_score=-LONG_MAX;
-    move best_move=*(moves.begin());
+    chessmove best_move=*(moves.begin());
     for (move_list::iterator i=moves.begin();
         i!=moves.end() && best_score<beta; ++i) {
         ChessBoard c=b;
